@@ -1102,6 +1102,53 @@ class AddRequest:
                 "lineSpacings": line_spacings,
                 "font": _font_to_dict(obj.font),
             }
+        elif isinstance(obj, TextLine):
+
+            def _font_to_dict(font: Optional[Font]) -> Optional[dict]:
+                if font:
+                    return {"name": font.name, "size": font.size}
+                return None
+
+            def _color_to_dict(color: Optional[Color]) -> Optional[dict]:
+                if color:
+                    return {
+                        "red": color.r,
+                        "green": color.g,
+                        "blue": color.b,
+                        "alpha": color.a,
+                    }
+                return None
+
+            # Build textElement with only non-null fields
+            text_element = {
+                "text": obj.text,
+            }
+
+            if obj.font:
+                text_element["font"] = _font_to_dict(obj.font)
+            if obj.color:
+                text_element["color"] = _color_to_dict(obj.color)
+            if obj.position:
+                text_element["position"] = FindRequest._position_to_dict(obj.position)
+
+            # TEXT_LINE structure matches paragraph line format (textElements only)
+            result = {
+                "type": "TEXT_LINE",
+                "position": (
+                    FindRequest._position_to_dict(obj.position)
+                    if obj.position
+                    else None
+                ),
+                "textElements": [text_element],
+            }
+
+            # Only include top-level font/color if they are not None
+            if obj.font:
+                result["font"] = _font_to_dict(obj.font)
+            if obj.color:
+                result["color"] = _color_to_dict(obj.color)
+
+            return result
         else:
             raise ValueError(f"Unsupported object type: {type(obj)}")
 
